@@ -8,7 +8,7 @@ from dbt.adapters.sql import SQLConnectionManager
 from dbt.contracts.connection import AdapterResponse
 from dbt.events import AdapterLogger
 
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from typing import Any, Optional, Dict
 from dbt.helper_types import Port
 
@@ -100,7 +100,7 @@ class TrinoNoneCredentials(TrinoCredentials):
     cert: Optional[str] = None
     http_scheme: HttpScheme = HttpScheme.HTTP
     http_headers: Optional[Dict[str, str]] = None
-    session_properties: Optional[Dict[str, Any]] = None
+    session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
 
     @property
@@ -117,9 +117,10 @@ class TrinoCertificateCredentials(TrinoCredentials):
     port: Port
     client_certificate: str
     client_private_key: str
+    user: Optional[str] = None
     cert: Optional[str] = None
     http_headers: Optional[Dict[str, str]] = None
-    session_properties: Optional[Dict[str, Any]] = None
+    session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
 
     @property
@@ -130,10 +131,6 @@ class TrinoCertificateCredentials(TrinoCredentials):
     def method(self):
         return "certificate"
 
-    @property
-    def user(self):
-        return None
-
     def trino_auth(self):
         return trino.auth.CertificateAuthentication(
             client_certificate=self.client_certificate,
@@ -149,7 +146,7 @@ class TrinoLdapCredentials(TrinoCredentials):
     password: str
     cert: Optional[str] = None
     http_headers: Optional[Dict[str, str]] = None
-    session_properties: Optional[Dict[str, Any]] = None
+    session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
 
     @property
@@ -175,7 +172,7 @@ class TrinoKerberosCredentials(TrinoCredentials):
     password: str
     cert: Optional[str] = None
     http_headers: Optional[Dict[str, str]] = None
-    session_properties: Optional[Dict[str, Any]] = None
+    session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
 
     @property
@@ -195,9 +192,10 @@ class TrinoJwtCredentials(TrinoCredentials):
     host: str
     port: Port
     jwt_token: str
+    user: Optional[str] = None
     cert: Optional[str] = None
     http_headers: Optional[Dict[str, str]] = None
-    session_properties: Optional[Dict[str, Any]] = None
+    session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
 
     @property
@@ -208,10 +206,6 @@ class TrinoJwtCredentials(TrinoCredentials):
     def method(self):
         return "jwt"
 
-    @property
-    def user(self):
-        return None
-
     def trino_auth(self):
         return trino.auth.JWTAuthentication(self.jwt_token)
 
@@ -220,9 +214,10 @@ class TrinoJwtCredentials(TrinoCredentials):
 class TrinoOauthCredentials(TrinoCredentials):
     host: str
     port: Port
+    user: Optional[str] = None
     cert: Optional[str] = None
     http_headers: Optional[Dict[str, str]] = None
-    session_properties: Optional[Dict[str, Any]] = None
+    session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
     OAUTH = trino.auth.OAuth2Authentication(
         redirect_auth_url_handler=trino.auth.WebBrowserRedirectHandler()
@@ -236,10 +231,6 @@ class TrinoOauthCredentials(TrinoCredentials):
     def method(self):
         return "oauth"
 
-    @property
-    def user(self):
-        return None
-
     def trino_auth(self):
         return self.OAUTH
 
@@ -385,7 +376,7 @@ class TrinoConnectionManager(SQLConnectionManager):
             schema=credentials.schema,
             http_scheme=credentials.http_scheme.value,
             http_headers=credentials.http_headers,
-            session_properties=credentials.session_properties,
+            session_properties=credentials.session_properties.copy(),
             auth=credentials.trino_auth(),
             isolation_level=IsolationLevel.AUTOCOMMIT,
             source="dbt-trino",
